@@ -1,7 +1,7 @@
 __author__ = 'Stephan Conrad <stephan@conrad.pics>'
 
 from pathlib import Path
-from exon.utils.fileutils import readfile, writefile
+from exon.utils.fileutils import readfile, writefile, writefileFromArray
 from exon.utils.command.execute import exec as run
 import os
 import re
@@ -279,12 +279,75 @@ class NetctlInterface(object):
         lines.append("Description='%s'" % self.description.strip('\'"'))
         lines.append('Interface=%s' % self.interface)
         lines.append('Connection=%s' % self.connection)
-        lines.append('IP=%s' % self.ip)
-        lines.append('Address=(%s)' % ' '.join(["'%s'" % x for x in self.address]))
-        lines.append('Routes=(%s)' % ' '.join(["'%s'" % x for x in self.routes]))
-        lines.append("Gateway='%s'" % self.gateway)
-        for l in lines:
-            print('', l, sep='\t')
+        if self.ip != "":
+            lines.append('IP=%s' % self.ip)
+        if len(self.address) > 0:
+            lines.append('Address=(%s)' % ' '.join(["'%s'" % x for x in self.address]))
+        if len(self.routes) > 0:
+            lines.append('Routes=(%s)' % ' '.join(["'%s'" % x for x in self.routes]))
+        if self.dns != "":
+            lines.append("Gateway='%s'" % self.gateway)
+        if len(self.address) > 0:
+            lines.append("DNS=(%s)" % ' '.join(["'%s'" % x for x in self.dns]))
+        if self.ip6 != "":
+            lines.append("IP6=%s" % self.ip6)
+        if len(self.address6) > 0:
+            lines.append("Address6=(%s)" % ' '.join(["'%s'" % x for x in self.address6]))
+        if len(self.routes6) > 0:
+            lines.append("Routes6=('%s')" % ' '.join(["'%s'" % x for x in self.routes6]))
+        if self.gateway6 != "":
+            lines.append("Gateway6='%s'" % self.gateway6)
+
+        writefileFromArray(self._cfgFile, lines)
+
+    def _runNetCtl(self, command):
+        cmd = 'netctl %s %s' % (command, self.name)
+        out = run(cmd)
+        self._lastError = out
+        self._lassCommand = cmd
+        return out.rc == 0
+
+    def restart(self):
+        return self._runNetCtl("restart")
+
+    def start(self):
+        return self._runNetCtl("start")
+
+    def stop(self):
+        return self._runNetCtl("stop")
+
+    def enable(self):
+        return self._runNetCtl("enable")
+
+    def disable(self):
+        return self._runNetCtl("disable")
+
+    def enableOrDisable(self):
+        if 'enabled' in self.changed:
+            if self.enabled:
+                return self.enable()
+            else:
+                return self.disable()
+        return True
+
+	class Netdev(object):
+	    def __init__(self, dev):
+	        self.dev = dev
+	        self._getData()
+
+        def _getData(self):
+	        self.ip = []
+	        self.ip6 = []
+	        out = exec("ip addr show dev {}".format(self.dev))
+	        if out.rc == 0:
+	            for line in out.stdout:
+	                line = line.strip()
+	                if line.startswith("link/ether"):
+	                    self.mac = line.split(" ")[1]
+	                elif line.startswith("inet "):
+	                    self.ip.append(line.split(" ")[1])
+	                elif line.startswith("inet6 "):
+	                    self.ip6.append(line.split(" ")[1])
 
 
 if __name__ == "__main__":
